@@ -1,6 +1,7 @@
 #!/bin/sh
 
-MY_OS=$(uname -s)
+MY_OS=$(uname -s )
+OS_EXTRA_DIR="arduino-1.0"
 
 if [ "$MY_OS" = "Linux" ]
 then
@@ -14,6 +15,17 @@ then
 	ARD_FILE=arduino-1.0-linux.tgz
 	ARD_URL=$ARD_BASE/$ARD_FILE
     fi
+elif [ "${MY_OS:0:5}" = "CYGWI" ]
+then
+	ARD_BASE=http://arduino.googlecode.com/files/
+	ARD_FILE=arduino-1.0-windows.zip
+	ARD_URL=$ARD_BASE/$ARD_FILE
+elif [ "${MY_OS:0:6}" = "Darwin" ]
+then
+	ARD_BASE=http://arduino.googlecode.com/files/
+	ARD_FILE=arduino-1.0-macosx.zip
+	ARD_URL=$ARD_BASE/$ARD_FILE
+	OS_EXTRA_DIR="Arduino.app/Contents/Resources/Java"
 else
     echo "Currently no support for non GNU/Linux platforms"
     echo "Contact the searduino team"
@@ -49,7 +61,7 @@ exec_comm()
 
 get_sources()
 {
-    exec_comm mkdir -p download-tmp
+    mkdir -p download-tmp
     exec_comm rm -f $ARD_FILE
     wget $ARD_URL
     exec_comm mv   $ARD_FILE download-tmp
@@ -58,18 +70,33 @@ get_sources()
 unpack_sources()
 {
     exec_comm cd download-tmp
-    exec_comm tar zxvf $ARD_FILE
+    if [ "$MY_OS" = "Linux" ]
+    then
+	exec_comm tar zxvf $ARD_FILE
+    elif [ "${MY_OS:0:5}" = "CYGWI" ]
+    then
+	exec_comm unzip $ARD_FILE
+    elif [ "${MY_OS:0:6}" = "Darwin" ]
+    then
+	exec_comm unzip $ARD_FILE
+    else
+	echo "Currently no support for non GNU/Linux platforms"
+	echo "Contact the searduino team"
+	exit 1
+    fi
     exec_comm cd ..
 }
 
 setup_sources()
 {
-#    exec_comm mkdir arduino-sources
-    exec_comm mkdir arduino-sources/core
-    exec_comm mkdir arduino-sources/variants
+    mkdir -p arduino-sources
+    mkdir -p arduino-sources/core
+    mkdir -p arduino-sources/variants
+    mkdir -p ard-ex
 
-    exec_comm cp -r download-tmp/arduino-1.0/hardware/arduino/cores/arduino/* arduino-sources/core
-    exec_comm cp -r download-tmp/arduino-1.0/hardware/arduino/variants/* arduino-sources/variants/
+    exec_comm cp -r download-tmp/${OS_EXTRA_DIR}/hardware/arduino/cores/arduino/* arduino-sources/core
+    exec_comm cp -r download-tmp/${OS_EXTRA_DIR}/hardware/arduino/variants/* arduino-sources/variants/
+    exec_comm cp -r download-tmp/${OS_EXTRA_DIR}/examples/* ard-ex/
 }
 
 
@@ -80,9 +107,9 @@ create_mk()
     exec_comm cp mk/arduino-sources/arduino-sources.mk        arduino-sources/
 }
 
-if [ -d arduino-sources/core ]
+if [ -f arduino-sources/core/WMath.cpp ]
 then
-    echo "Already downloaded, skipping download and unpack"
+    echo "Arduino code already downloaded, skipping download and unpack"
 else
     get_sources
     unpack_sources
@@ -90,3 +117,6 @@ else
 fi
 
 create_mk
+
+
+exit 0
\ No newline at end of file
