@@ -19,8 +19,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-export LD_LIBRARY_PATH=/tmp/TMP_INSTALL3/lib
-export PYTHONPATH=/tmp/TMP_INSTALL3/lib
+export LD_LIBRARY_PATH=/opt/searduino/lib
+export PYTHONPATH=/opt/searduino/lib
 
-/tmp/TMP_INSTALL3/bin/pardon.py
+/opt/searduino/bin/pardon.py $*
 
